import configparser

def settingUp():
    '''
    This function uses the parameters set by user to connect to PGadmin database

    The purpose of this function is to get the correct parameters and credentials
    from the user to connect to PGAdmin 4 sql data base via sqlalchamy engine. The
    function uses the data provided by the user and creates a .ini file named sqlconfig.ini

    The values for the parameters can be found on pgAdmin 4. Most of them are under properties.
    Hints: 
        DATABASE_TYPE: Server type on pgAdmin 4 (all lower case)
        DBAPI: psycopg2
        HOST: Host name / address on pgAdmin 4 
        USER: Username on pgAdmin 4
        PASSWORD: Password created by user when setting up pgAdmin 4
        DATABASE: The name of the database under Databases in pgAdmin 4
        PORT: Port in pgAdmin 4

    Output:
        .ini file contained the paremeters and credentials 
    '''
    config = configparser.ConfigParser()
    config['DEFAULT'] = {'DATABASE_TYPE': 'Replace',
                        'DBAPI': 'Replace',
                        'HOST': 'Replace',
                        'USER': 'Replace',
                        'PASSWORD': 'Replace',
                        'DATABASE': 'Replace',
                        'PORT': 'Replace'}
    with open('sqlconfig.ini', 'w') as configfile:
        config.write(configfile)






import pandas as pd 
from bs4 import BeautifulSoup
from urllib.request import urlopen
from urllib.request import Request
import pandas as pd
from collections import defaultdict
from tqdm import tqdm
from typing import Optional


from vaderSentiment.vaderSentiment import SentimentIntensityAnalyzer
analyzer = SentimentIntensityAnalyzer()

obj = SentimentIntensityAnalyzer()



def getSnpCompanies() -> Optional[list]:
    '''
    This method scrapes the snp500 stocks from wikidpedia. 

    The purpose of this method is to retrieve data from
    wikipedia as its constantly being updated. 

    Returns: 
        list: A list of ticker symbols 
    '''
    tickers = []
    table=pd.read_html('https://en.wikipedia.org/wiki/List_of_S%26P_500_companies')
    snp_df = table[0]
    symbol = snp_df['Symbol']
    for ticker in symbol:
        tickers.append(ticker)
    return tickers



def getStockContent(tickers:list) -> Optional[pd.DataFrame]:
    '''
    This method scrapes stock info on each stock

    The purpose of this method is to use the list of 
    snp500 stocks and scrape stock name, stock sector,
    stock type, stock region ,stock info 

    Args:
        tickers: Stock tickers of the snp500 stocks

    Returns:
        Pandas dataframe: A datatable of stock info in pandas format
    '''
    dict_name = ['ticker','stock_name','stock_sector','stock_type','stock_region','stock_info']
    stock_data = {}
    for i in range(len(dict_name)):
        stock_data[dict_name[i]] = []

    for ticker in tqdm(tickers):
        if "." in ticker:
            ticker = ticker.replace(".","-")
        finviz_url = 'https://finviz.com/quote.ashx?t='
        news_tables = {}
        url = finviz_url + ticker
        try:
            req = Request(url=url,headers={'user-agent': 'my-app/0.0.1'})
            resp = urlopen(req)
            html = BeautifulSoup(resp, features="lxml")
            stock_name = html.find_all('a', {'class':'tab-link'})[12].text
            stock_sector= html.find_all('a', {'class':'tab-link'})[13].text
            stock_type= html.find_all('a', {'class':'tab-link'})[14].text
            stock_region= html.find_all('a', {'class':'tab-link'})[15].text
            stock_info= html.find('td', {'class':'fullview-profile'}).text
        except Exception as e:
            stock_name='Unknown'
            stock_sector='Unknown'
            stock_type='Unknown'
            stock_region='Unknown'
            stock_info='Unknown'
            print(e, url)
        
        finally:
            stock_value = [ticker,stock_name,stock_sector,stock_type,stock_region,stock_info]
            for i in range(len(stock_value)):
                    stock_data[dict_name[i]].append(stock_value[i])


    df = pd.DataFrame.from_dict(stock_data)          
    return df



def getNewsHeadlines(tickers:list) -> Optional[pd.DataFrame]:
    '''
    This method scrapes news headlines of the stocks in the snp500

    The purpose of this method is to use the stock tickers and scrapes 
    the top 100 news headlines related to the stock

    Args:
        tickers: Stock tickers of the snp500 stocks

    Returns:
        Pandas dataframe: A datatable of stock info in pandas format

    '''
    dict_name = ['ticker','headline','date']

    headline_data = {}
    for i in range(len(dict_name)):
        headline_data[dict_name[i]] = []
    
    for ticker in tqdm(tickers):
        if "." in ticker:
            ticker = ticker.replace(".","-")
        try:

            finviz_url = 'https://finviz.com/quote.ashx?t='
            news_tables = {}
            url = finviz_url + ticker
            req = Request(url=url,headers={'user-agent': 'my-app/0.0.1'})
            resp = urlopen(req)
            html = BeautifulSoup(resp, features="lxml")
            n=100
            news_tables = html.find(id='news-table')
            news_tables[ticker] = news_tables
            df = news_tables[ticker]
            df_tr = df.findAll('tr')
            for i, table_row in enumerate(df_tr):
                article_headline = table_row.a.text
                td_text = table_row.td.text
                article_date = td_text.strip()
                headline_value = [ticker,article_headline,article_date]

                for i in range(len(headline_value)):
                    headline_data[dict_name[i]].append(headline_value[i])
            
                if i == n-1:
                    break
        except Exception as e:
            print(e, ticker)
            headline_value = [ticker,article_headline,article_date]
            for i in range(len(headline_value)):
                headline_data[dict_name[i]].append("unknown")
    df = pd.DataFrame.from_dict(headline_data)    
    return df





def getTwiterData():
    try:
        pass
    
    except Exception as e:
        print(e)


  


import unittest
import pandas as pd

if __name__ == "__main__" and __package__ is None:
    from sys import path
    from os.path import dirname as dir

    path.append(dir(path[0]))
    __package__ = "examples"

from stock_scraper_AiCore import stock_scraper

class StockScraperTestCase(unittest.TestCase):

    def test_snpCompanies(self):
        actual_value = type(stock_scraper.getSnpCompanies())
        expected_values = list

        self.assertEqual(expected_values, actual_value)

    def test_StockContent(self):
        tickers = ['TSLA', 'MSFT']
        actual_value = type(stock_scraper.getStockContent(tickers=tickers))
        expected_values = pd.DataFrame

        self.assertEqual(expected_values, actual_value)
    
    def test_NewsHeadlines(self):
        tickers = ['TSLA', 'MSFT']
        actual_value = type(stock_scraper.getNewsHeadlines(tickers=tickers))
        expected_values = pd.DataFrame

        self.assertEqual(expected_values, actual_value)




import unittest
import pandas as pd


if __name__ == "__main__" and __package__ is None:
    from sys import path
    from os.path import dirname as dir

    path.append(dir(path[0]))
    __package__ = "examples"

from stock_scraper_AiCore.data_base import SqlDB

class DataBaseTestCase(unittest.TestCase):
    def test_tableExists(self):
        self.config_sql = SqlDB()
        self.dataTables = ['stock_content','stock_headlines','stock_sentiment']


        for dataTable in self.dataTables:
            actual_value = self.config_sql.tableExists(table_name=str(dataTable))
            self.assertIsInstance(actual_value, bool)
    
    def test_retriveTableInfo(self):
        self.config_sql = SqlDB()
        self.dataTables = ['a']
        expected_values = pd.DataFrame

        for dataTable in self.dataTables:
            actual_value = type(self.config_sql.retriveTableInfo(table_name=str(dataTable)))
            self.assertEqual(actual_value,expected_values)

    def test_createTable(self):
        self.config_sql = SqlDB()
        self.dataTables = ['a','b','c']
        self.content = pd.DataFrame({'a':[0], 'b':[0],'c':[0]})
        expected_values = bool
        
        for dataTable in self.dataTables:
            tableExists = self.config_sql.tableExists(table_name=str(dataTable))
            if tableExists == True:
                self.config_sql.deleteTable(table_name=str(dataTable))
            creat_db = self.config_sql.createTable(table_name=str(dataTable),dt_contents=self.content)
            actual_value = type(self.config_sql.tableExists(table_name=str(dataTable)))
            self.assertEqual(actual_value,expected_values)
    
    def test_appendData(self):
        self.config_sql = SqlDB()
        self.dataTables = ['a','b','c']
        self.content = pd.DataFrame({'a':[1,2], 'b':[3,4],'c':[5,6]})
        expected_values = pd.DataFrame

        for dataTable in self.dataTables:
            self.config_sql.appendData(table_name=str(dataTable),dt_contents=self.content)
            actual_value = type(self.config_sql.retriveTableInfo(table_name=dataTable))
            self.assertEqual(actual_value,expected_values)


    def test_getNewRows(self):
        config_sql = SqlDB()
        self.new_dt = pd.DataFrame({'a':[1,2], 'b':[3,4],'c':[5,6]})
        self.source_dt = pd.DataFrame({'a':[1,2], 'b':[3,4]})
        expected_values = pd.DataFrame
        actual_value= type(config_sql.getNewRows(new_dt=self.new_dt,source_dt=self.source_dt))
        self.assertEqual(actual_value,expected_values)

        







import unittest
import pandas as pd

if __name__ == "__main__" and __package__ is None:
    from sys import path
    from os.path import dirname as dir

    path.append(dir(path[0]))
    __package__ = "examples"

from stock_scraper_AiCore import process
stockContent_name = 'testing_stockData'
headline_name = 'testing_headlineData'
sentiment_name = 'testing_sentimentData'
class ProcessTestCase(unittest.TestCase):


    def test_stockData(self):
        process.stockData(stockContent_name=stockContent_name, updateFlag=True)
        actual_value = type(process.tableExitsCheck(table_exists=True, table_name=stockContent_name))
        expected_values = pd.DataFrame

        self.assertEqual(expected_values, actual_value)
    
    def test_stockHeadlineData(self):
        process.stockHeadlineData(stockInfoDatatable_name=stockContent_name,updateFlag=True,headlineDatatable_name=headline_name)
        actual_value = type(process.tableExitsCheck(table_exists=True, table_name=headline_name))
        expected_values = pd.DataFrame

        self.assertEqual(expected_values, actual_value)
    
    def test_sentimentData(self):
        process.sentimentData(sentimentDatatable_name=sentiment_name,updateFlag=True,headlineDatatable_name=headline_name)
        actual_value = type(process.tableExitsCheck(table_exists=True, table_name=headline_name))
        expected_values = pd.DataFrame

        self.assertEqual(expected_values, actual_value)




from .config import settingUp
import configparser
import os.path
import getpass

def sqlCreds(DATABASE_TYPE,DBAPI,HOST,USER,PASSWORD,DATABASE,PORT):
    '''
    This function uses the parameters set by user to connect to PGadmin database

    The purpose of this function is to get the correct parameters and credentials
    from the user to connect to PGAdmin 4 sql data base via sqlalchamy engine. The
    function uses the data provided by the user and creates a .ini file named sqlconfig.ini

    The values for the parameters can be found on pgAdmin 4. Most of them are under properties.
    Hints: 
        DATABASE_TYPE: Server type on pgAdmin 4 (all lower case)
        DBAPI: psycopg2
        HOST: Host name / address on pgAdmin 4 
        USER: Username on pgAdmin 4
        PASSWORD: Password created by user when setting up pgAdmin 4
        DATABASE: The name of the database under Databases in pgAdmin 4
        PORT: Port in pgAdmin 4

    Output:
        .ini file contained the paremeters and credentials 
    '''

    config = configparser.ConfigParser()
    config['DEFAULT'] = {'DATABASE_TYPE': DATABASE_TYPE,
                        'DBAPI': DBAPI,
                        'HOST': HOST,
                        'USER': USER,
                        'PASSWORD': PASSWORD,
                        'DATABASE': DATABASE,
                        'PORT': PORT}
    with open('sqlconfig.ini', 'w') as configfile:
        config.write(configfile)


print('Welcome to stock scraper')
print('Lets begin...')
print('Checking if config file is populated')
requiredFields = []
config_parser = configparser.ConfigParser()
settingUp()
config_parser.read('sqlconfig.ini')
DATABASE_TYPE = config_parser['DEFAULT']['DATABASE_TYPE']
DBAPI = config_parser['DEFAULT']['DBAPI']
HOST = config_parser['DEFAULT']['HOST']
USER = config_parser['DEFAULT']['USER']
PASSWORD = config_parser['DEFAULT']['PASSWORD']
DATABASE = config_parser['DEFAULT']['DATABASE']
PORT = config_parser['DEFAULT']['PORT']
configValues = ['DATABASE_TYPE','DBAPI','HOST','USER','PASSWORD','DATABASE','PORT']
configParameters = [DATABASE_TYPE,DBAPI,HOST,USER,PASSWORD,DATABASE,PORT]
counter = 0 
for parameters in configParameters:
    if parameters=='Replace':
        requiredFields.append(configValues[counter])
    counter = +1
if not requiredFields:
    print('Config file has been populated')
    print('Starting scraper')
    from .process import stockData,stockHeadlineData,sentimentData

    # Declaring datatable names
    dt_stockContent = "stock_content"
    dt_headlines = "stock_headlines"
    dt_sentiment = "stock_sentiment"

    stockData(stockContent_name=dt_stockContent, updateFlag=True)
    stockHeadlineData(headlineDatatable_name = dt_headlines, stockInfoDatatable_name = dt_stockContent, updateFlag = True)
    sentimentData(sentimentDatatable_name=dt_sentiment, updateFlag=True, headlineDatatable_name=dt_headlines)
    print('Scraping complete')
else:
    print('Config file has NOT been populated')
    print('PGAdmin credentials required to proceed')
    credsQuestion = input('Would you like to Enter credentials now?(y/n)')
    if credsQuestion == 'y':
        print('Please enter the value for the following parameters')
        DATABASE_TYPE = input('DATABASE_TYPE: ')
        DBAPI = input('DBAPI: ')
        HOST = input('HOST: ')
        USER = input('USER: ')
        PASSWORD = getpass.getpass('PASSWORD: ')
        DATABASE = input('DATABASE: ')
        PORT = input('PORT: ')
        sqlCreds(DATABASE_TYPE=DATABASE_TYPE.strip(), DBAPI=DBAPI.strip(),HOST=HOST.strip(),USER=USER.strip(),PASSWORD=PASSWORD.strip(),DATABASE=DATABASE.strip(),PORT=PORT.strip())

        from .process import stockData,stockHeadlineData,sentimentData

        # Declaring datatable names
        dt_stockContent = "stock_content"
        dt_headlines = "stock_headlines"
        dt_sentiment = "stock_sentiment"

        stockData(stockContent_name=dt_stockContent, updateFlag=True)
        stockHeadlineData(headlineDatatable_name = dt_headlines, stockInfoDatatable_name = dt_stockContent, updateFlag = True)
        sentimentData(sentimentDatatable_name=dt_sentiment, updateFlag=True, headlineDatatable_name=dt_headlines)
        print('Scraping complete')
    else:
        print('You did not select y')
        print('Please populate congig.py file and re-run the code')
        print('The code is now exiting...')
        print('Scraping complete')




import psycopg2
from sqlalchemy import create_engine, engine
import pandas as pd
import os
import sqlalchemy
import configparser
from typing import Optional
from sqlalchemy import MetaData
from sqlalchemy.ext.declarative import declarative_base


class SqlDB:
    '''
    This class is used to perform SQL datbase activities

    
    '''
    def __init__(self):
        '''
        This method is used to establish the database connection

        The purpose of this method is to use the sqlconfig.ini
        file to create a connection with the database using the 
        sqlalchmy engine.
        '''
        config_parser = configparser.ConfigParser()
        config_parser.read('sqlconfig.ini')
        DATABASE_TYPE = config_parser['DEFAULT']['DATABASE_TYPE']
        DBAPI = config_parser['DEFAULT']['DBAPI']
        HOST = config_parser['DEFAULT']['HOST']
        USER = config_parser['DEFAULT']['USER']
        PASSWORD = config_parser['DEFAULT']['PASSWORD']
        DATABASE = config_parser['DEFAULT']['DATABASE']
        PORT = config_parser['DEFAULT']['PORT']
        engine = create_engine(f"{DATABASE_TYPE}+{DBAPI}://{USER}:{PASSWORD}@{HOST}:{PORT}/{DATABASE}")
        self.engine = engine
    
    def deleteTable(self,table_name: str):
            Base = declarative_base()
            metadata = MetaData()
            metadata.reflect(bind=self.engine)
            table = metadata.tables[table_name]
            if table is not None:
                Base.metadata.drop_all(self.engine, [table], checkfirst=True)
    
    
    def tableExists(self,table_name: str) -> Optional[bool]:
        '''
        This method checks if a table exists in a database. 

        Args:
            table_name: The name of the table to check if it exits
            in database
        
        Returns: 
            bool: True if the table exists. False if it doesnt exist
        '''
        table_exists = sqlalchemy.inspect(self.engine).has_table(table_name)

        return table_exists

    def retriveTableInfo(self,table_name: str) -> Optional[pd.DataFrame]:
        '''
        This method returns the data from a table

        Args:
            table_name: The name of the table to check if it exits
            in database

        Returns:
            Pandas dataframe: The data of the table in pandas format
        '''
        stock_db = pd.read_sql_table(table_name, self.engine)

        return stock_db
    
    def createTable(self,table_name: str,dt_contents:pd.DataFrame):
        '''
        This method creates a table in the database

        Args: 
            table_name: The name of the table to check if it exits
            in database

            dt_contents: The data to be inserted into the table        
        '''

        creatededDt = dt_contents.to_sql(table_name, self.engine, index=False)

    def appendData(self,table_name: str,dt_contents:pd.DataFrame):
        '''
        This method appends data to a table in the database

        Args: 
            table_name: The name of the table to check if it exits
            in database

            dt_contents: The data to be inserted into the table        
        '''
        dt_contents.to_sql(table_name, self.engine, if_exists='append',index=False)
    
    def getNewRows(self,source_dt: pd.DataFrame, new_dt: pd.DataFrame):
        '''
        This method checks if data from one datable exists in another

        Args: 
            source_dt: The source datatable that to be checks against 

            new_dt: The new datatable to check

        Returns:
            Pandas dataframe: Datatable with data that does not exist in source_dt
        '''

        merged_df = source_dt.merge(new_dt, indicator=True, how='outer')
        changed_rows_df = merged_df[merged_df['_merge'] == 'right_only']
        return changed_rows_df.drop('_merge', axis=1)

# db = SqlDB()
# db.deleteTable(table_name='a')





from vaderSentiment.vaderSentiment import SentimentIntensityAnalyzer
analyzer = SentimentIntensityAnalyzer()
import pandas as pd
from typing import Optional

obj = SentimentIntensityAnalyzer()

def sentimentAnalysis(ticker:list,headlines:list, date:list) -> Optional[pd.DataFrame]:
    '''
    This function is used to perform sentiment analysis on stocks

    The purpose of this function is to create a dictionary, use 
    each headline from the headlines list and perform sentiment analysis

    Args:
        ticker: Stock ticker symbol of stock

        headlines: List of headlines

        date: The date of the headline
    
    Returns:
        Pandas dataframe: a datatable containing sentiment data
    '''
    dict_name = ['date','ticker','headline','sentiment']
    sentiment_data = {}
    for i in range(len(dict_name)):
        sentiment_data[dict_name[i]] = []

    counter = 0
    for headline in headlines:
        if headline == "Unknown":
            pass
        else:
            sentiment_eg=obj.polarity_scores(headline)
            sentiment_compound = sentiment_eg['compound']
            sentiment_value = [date[counter],ticker[counter],headline,sentiment_compound]
            counter +=1
            for i in range(len(sentiment_value)):
    
                    sentiment_data[dict_name[i]].append(str(sentiment_value[i]))
    df = pd.DataFrame.from_dict(sentiment_data) 

    return df





from os import path
from setuptools import setup
from setuptools import find_packages


setup(
    name='AiCoreSentimentStock_scraper2021EtaCohort', ## This will be the name your package will be published with
    version='0.0.2', 
    description='scraping stock data',
    #url='https://github.com/IvanYingX/project_structure_pypi.git', # Add the URL of your github repo if published 
                                                                   # in GitHub
    author='Tamim Ehsan', # Your name
    license='MIT',
    
    packages=find_packages(), # This one is important to explain. See the notebook for a detailed explanation
    install_requires=['beautifulsoup4==4.9.3','bs4==0.0.1','certifi==2021.5.30','charset-normalizer==2.0.4','colorama==0.4.4','greenlet==1.1.1','idna==3.2','lxml==4.6.3','numpy==1.21.2','pandas','psycopg2==2.9.1','python-dateutil==2.8.2','pytz==2021.1','requests==2.26.0','six==1.16.0','soupsieve==2.2.1','SQLAlchemy==1.4.23','tqdm==4.62.2','urllib3==1.26.6','vaderSentiment==3.3.2'], # For this project we are using two external libraries
                                                     # Make sure to include all external libraries in this argument
)


#from stock_scraper import StockScraper
from .stock_scraper import getSnpCompanies,getStockContent,getNewsHeadlines
from .data_base import SqlDB
import pandas as pd
from .Sentiment_analysis import sentimentAnalysis

#configuing stockscraper because it is a class
#config_stock = StockScraper()
config_sql = SqlDB()



def tableExitsCheck(table_exists:bool, table_name:str):
        if table_exists == False:
            raise ValueError('Data table doesnt exist... Creating one')
        else:
            print("Database exists")    
            retrieve_table = config_sql.retriveTableInfo(table_name=table_name)

        return retrieve_table

def createDataTable(table_name:str, dt_contents):
        create_table = config_sql.createTable(table_name=table_name, dt_contents=dt_contents)
        retrieve_table = config_sql.retriveTableInfo(table_name=table_name)
        print("Data table:",table_name, "Has been created")

def updateStockInfo(updateFlag:bool, retrieve_table):
        if updateFlag == True:
            stock_list = getSnpCompanies()
            content = getStockContent(tickers=stock_list)
        else:
            stock_list = retrieve_table['ticker']
            content = getStockContent(tickers=stock_list)    
        return content
def pushData(source_dt,new_dt,table_name):
        fresh_dt = config_sql.getNewRows(source_dt=source_dt, new_dt=new_dt)
        config_sql.appendData(table_name=table_name, dt_contents=fresh_dt) 


def stockData(stockContent_name:str ,updateFlag:bool):
    '''
    This function is used to perform stock data activities

    The purpose of this function is to create a stock info database, 
    retrieve the snp 500 companies from wikipedia, get
    the stock name, stock industry stock sector,stock type
    stock region, stock_info for each stock, and populate 
    the database with that data

    Args:
        stockContent_name: The name of the database for the stock contents

        updateFlag: A flag to be used if updating stock content is required or not
    '''
    print("Starting stock details extraction")
    stock_col = ['ticker','stock_name','stock_sector','stock_type','stock_region','stock_info']
    df = pd.DataFrame(columns=stock_col)
    content = df
    table_exists = config_sql.tableExists(table_name=stockContent_name)

    try: 
        tableExitsCheck(table_exists=table_exists, table_name=stockContent_name)
        retrieve_table = config_sql.retriveTableInfo(table_name=stockContent_name)

    except ValueError as e:
        print(e)
        createDataTable(table_name=stockContent_name, dt_contents=content)
        retrieve_table = config_sql.retriveTableInfo(table_name=stockContent_name)

    finally:
        content = updateStockInfo(updateFlag=updateFlag, retrieve_table=retrieve_table)
        pushData(source_dt=retrieve_table, new_dt=content, table_name=stockContent_name)
        # new_dt = config_sql.getNewRows(source_dt=retrieve_table, new_dt=content)
        # config_sql.appendData(table_name=stockContent_name, dt_contents=new_dt)       
    print("Stock details extraction complete")


def stockHeadlineData(stockInfoDatatable_name:str,updateFlag:bool,headlineDatatable_name:str):
        '''
        This function is used to retrieve headlines about the stock 

        The purpose of this function is create a database for headlines, 
        use the stock info database to retrieve headlines about the stock,
        and populate the headlines database

        Args:
            stockInfoDatatable_name: The stock info database name. This gets used to retrieve headlines

            updateFlag: A flag to be used if updating stock content is required or not

            headlineDatatable_name: The stock headline database name 
        '''
        print("Starting headlines extraction")
        config_sql = SqlDB()
        headline_col = ['ticker', 'headline', 'date']
 
        headline_tableExists = config_sql.tableExists(table_name=headlineDatatable_name)
        try:
            tableExitsCheck(table_exists=headline_tableExists, table_name=headlineDatatable_name)
            retrieve_table = config_sql.retriveTableInfo(table_name=headlineDatatable_name)
        except ValueError as e:
            print(e)
            df = pd.DataFrame(columns=headline_col)

            createDataTable(table_name=headlineDatatable_name, dt_contents=df)
            retrieve_table = config_sql.retriveTableInfo(table_name=headlineDatatable_name)

        finally:
            if updateFlag == True:
                
                retrieve_headline_table = config_sql.retriveTableInfo(table_name=headlineDatatable_name)
                retrieve_stock_info = config_sql.retriveTableInfo(table_name=stockInfoDatatable_name)
                dt_tickers = retrieve_stock_info['ticker'].tolist()
                new_dt= getNewsHeadlines(dt_tickers)
                original_dt = retrieve_headline_table

            else:
                retrieve_headline_table = config_sql.retriveTableInfo(table_name=headlineDatatable_name)
                new_dt = retrieve_headline_table
                original_dt = retrieve_headline_table
            append_dt = config_sql.getNewRows(source_dt=original_dt, new_dt=new_dt)

            config_sql.appendData(table_name=headlineDatatable_name, dt_contents=append_dt)
        print("Headlines extraction complete")

#stockHeadlineData(stockInfoDatatable_name = 'stock_content', updateFlag=True, headlineDatatable_name='stock_headlines')

def sentimentData(sentimentDatatable_name:str ,updateFlag:bool, headlineDatatable_name:str):
    '''
    This function is used to perform sentiment analysis activities

    The purpose of this function is to create a sentiment datatbale, 
    use the headlines from the headline datatable to perform sentiment
    analysis and populate the sentiment datatable

    Args: 
        sentimentDatatable_name: The name of the sentiment datatable
        
        updateFlag: A flag to be used if updating stock content is required or not

        headlineData_name: The name of the headline datatable 
    '''
    print("Starting sentiment analysis")
    sentiment_col = ['date','ticker','headline','sentiment']
    content = pd.DataFrame(columns=sentiment_col)
    sentiment_tableExists = config_sql.tableExists(table_name=sentimentDatatable_name)

    try:
        if sentiment_tableExists == False:
            raise ValueError('Data table doesnt exist... Creating one')
        else:
            retrieve_sentiment_table = config_sql.retriveTableInfo(table_name=sentimentDatatable_name)
            print("Datatable already exists")
    except ValueError as e:
        create_table = config_sql.createTable(table_name=sentimentDatatable_name, dt_contents=content)
        retrieve_sentiment_table = config_sql.retriveTableInfo(table_name=sentimentDatatable_name)
        print("Data table:",sentimentDatatable_name, "Created")
    finally:
        if updateFlag == True:
            retrieve_headline_table = config_sql.retriveTableInfo(table_name=headlineDatatable_name)
            tickersList = retrieve_headline_table['ticker'].tolist()
            dt_headlines = retrieve_headline_table['headline'].tolist()
            dt_date = retrieve_headline_table['date'].tolist()
            new_dt=sentimentAnalysis(ticker=tickersList, headlines=dt_headlines, date=dt_date)
            append_dt = config_sql.getNewRows(source_dt=retrieve_sentiment_table, new_dt=new_dt)
            config_sql.appendData(table_name=sentimentDatatable_name, dt_contents=append_dt)

    print("Sentiment analysis complete")
